@@ -93,6 +93,28 @@ def _parse_box_dots(bx, item, setting=False):
     raise BoxError("Could not split box dots properly")
 
 
+def _get_dot_paths(bx, current=""):
+    """A generator of all the end node keys in a box in box_dots format"""
+
+    def handle_dicts(sub_bx, paths=""):
+        for key, value in sub_bx.items():
+            yield f"{paths}.{key}" if paths else key
+            if isinstance(value, dict):
+                yield from handle_dicts(value, f"{paths}.{key}" if paths else key)
+            elif isinstance(value, list):
+                yield from handle_lists(value, f"{paths}.{key}" if paths else key)
+
+    def handle_lists(bx_list, paths=""):
+        for i, value in enumerate(bx_list):
+            yield f"{paths}[{i}]"
+            if isinstance(value, list):
+                yield from handle_lists(value, f"{paths}[{i}]")
+            if isinstance(value, dict):
+                yield from handle_dicts(value, f"{paths}[{i}]")
+
+    yield from handle_dicts(bx, current)
+
+
 def _get_box_config():
     return {
         # Internal use only
@@ -692,17 +714,20 @@ class Box(dict):
             convert_and_set(key, kwargs[key])
 
     def setdefault(self, item, default=None):
-        # Have to use a try except instead of "item in self" as box_dots may not be in iterable
-        try:
-            return self[item]
-        except KeyError:
-            if isinstance(default, dict):
-                default = self._box_config["box_class"](default, **self.__box_config())
-            if isinstance(default, list):
-                default = box.BoxList(default, **self.__box_config())
-            self[item] = default
+        if item in self:
             return self[item]
 
+        if self._box_config["box_dots"]:
+            if item in _get_dot_paths(self):
+                return self[item]
+
+        if isinstance(default, dict):
+            default = self._box_config["box_class"](default, **self.__box_config())
+        if isinstance(default, list):
+            default = box.BoxList(default, **self.__box_config())
+        self[item] = default
+        return self[item]
+
     def _safe_attr(self, attr):
         """Convert a key into something that is accessible as an attribute"""
         allowed = string.ascii_letters + string.digits + "_"
