@@ -26,6 +26,7 @@ import pytest
 import ruamel.yaml as yaml
 
 from box import Box, BoxError, BoxKeyError, BoxList, ConfigBox, SBox, box
+from box.box import _get_dot_paths  # type: ignore
 
 
 def mp_queue_test(q):
@@ -312,6 +313,24 @@ class TestBox:
         a.setdefault("x.y", 20)
         assert a["x.y"] == 10
 
+        a["lists"] = [[[{"test": "here"}], {1, 2}], (4, 5)]
+        assert list(_get_dot_paths(a)) == [
+            "x",
+            "x.y",
+            "lists",
+            "lists[0]",
+            "lists[0][0]",
+            "lists[0][0][0]",
+            "lists[0][0][0].test",
+            "lists[0][1]",
+            "lists[1]",
+        ]
+
+        t = Box({"a": 1}, default_box=True, box_dots=True, default_box_none_transform=False)
+        assert t.setdefault("b", [1, 2]) == [1, 2]
+        assert t == Box(a=1, b=[1, 2])
+        assert t.setdefault("c", [{"d": 2}]) == BoxList([{"d": 2}])
+
     def test_from_json_file(self):
         bx = Box.from_json(filename=data_json_file)
         assert isinstance(bx, Box)
@@ -1219,3 +1238,46 @@ class TestBox:
 
         out2 = BoxList.from_yaml("---")
         assert out2 == BoxList()
+
+    def test_setdefault_simple(self):
+        box = Box({"a": 1})
+        box.setdefault("b", 2)
+        box.setdefault("c", "test")
+        box.setdefault("d", {"e": True})
+        box.setdefault("f", [1, 2])
+
+        assert box["b"] == 2
+        assert box["c"] == "test"
+        assert isinstance(box["d"], Box)
+        assert box["d"]["e"] == True
+        assert isinstance(box["f"], BoxList)
+        assert box["f"][1] == 2
+
+    def test_setdefault_dots(self):
+        box = Box({"a": 1}, box_dots=True)
+        box.setdefault("b", 2)
+        box.c = {"d": 3}
+        box.setdefault("c.e", "test")
+        box.setdefault("d", {"e": True})
+        box.setdefault("f", [1, 2])
+
+        assert box.b == 2
+        assert box.c.e == "test"
+        assert isinstance(box["d"], Box)
+        assert box.d.e == True
+        assert isinstance(box["f"], BoxList)
+        assert box.f[1] == 2
+
+    def test_setdefault_dots_default(self):
+        box = Box({"a": 1}, box_dots=True, default_box=True)
+        box.b.c.d.setdefault("e", 2)
+        box.c.setdefault("e", "test")
+        box.d.e.setdefault("f", {"g": True})
+        box.e.setdefault("f", [1, 2])
+
+        assert box["b.c.d"].e == 2
+        assert box.c.e == "test"
+        assert isinstance(box["d.e.f"], Box)
+        assert box.d.e["f.g"] == True
+        assert isinstance(box["e.f"], BoxList)
+        assert box.e.f[1] == 2
